@@ -246,6 +246,7 @@ const char* const* SPVM_OPCODE_C_ID_NAMES(void) {
     "MOVE_FLOAT",
     "MOVE_DOUBLE",
     "MOVE_OBJECT",
+    "MOVE_UNDEF",
     "MOVE_REF",
     "CONVERT_BYTE_TO_SHORT",
     "CONVERT_BYTE_TO_INT",
@@ -324,6 +325,10 @@ const char* const* SPVM_OPCODE_C_ID_NAMES(void) {
     "LE_LONG",
     "LE_FLOAT",
     "LE_DOUBLE",
+    "CMP_INT",
+    "CMP_LONG",
+    "CMP_FLOAT",
+    "CMP_DOUBLE",
     "IS_UNDEF",
     "IS_NOT_UNDEF",
     "STRING_EQ",
@@ -332,6 +337,7 @@ const char* const* SPVM_OPCODE_C_ID_NAMES(void) {
     "STRING_GE",
     "STRING_LT",
     "STRING_LE",
+    "STRING_CMP",
     "BOOL_INT",
     "BOOL_LONG",
     "BOOL_FLOAT",
