@@ -10,8 +10,7 @@ SPVM::Math - Mathmatical functions
 
   use SPVM::Math;
   
-  my $pi = SPVM::Math->pi;
-  my $sin = SPVM::Math->sin($pi / 4);
+  my $sin = SPVM::Math->sin(SPVM::Math->PI / 4);
   
 =head1 DESCRIPTION
 
@@ -19,6 +18,18 @@ L<SPVM::Math> defines mathmatical functions.
 
 =head1 STATIC METHODS
 
+=head2 E
+
+  sub E : double ()
+
+The double value that is closer than any other to e, the base of the natural logarithms.
+
+=head2 PI
+
+  sub PI : double ()
+
+The double value that is closer than any other to pi, the ratio of the circumference of a circle to its diameter.
+
 =head2 FE_DOWNWARD
 
   sub FE_DOWNWARD : int ()
@@ -109,6 +120,18 @@ NAN constant value in C99 math.h.
 
 NAN constant value for float type in C99 math.h.
 
+=head2 abs
+
+  sub abs : int ($x : int);
+
+Get the abusolute value of a int value.
+
+=head2 labs
+
+  sub labs : long ($x : long);
+
+Get the abusolute value of a long value.
+
 =head2 acos
 
   sub acos : double ($x : double)
@@ -463,18 +486,6 @@ cpow function in C99 complex.h.
 
 cpowf function in C99 complex.h.
 
-=head2 cproj
-
-  sub cproj : SPVM::Complex_2d ($z : SPVM::Complex_2d)
-
-cproj function in C99 complex.h.
-
-=head2 cprojf
-
-  sub cprojf : SPVM::Complex_2f ($z : SPVM::Complex_2f)
-
-cprojf function in C99 complex.h.
-
 =head2 cscamul
 
   sub cscamul : SPVM::Complex_2d ($c : double, $z : SPVM::Complex_2d)
@@ -1021,12 +1032,6 @@ nexttoward function in C99 math.h.
 
 nexttowardf function in C99 math.h.
 
-=head2 pi
-
-  sub pi : double ()
-
-pi constant value. 3.141592653589793115997963468544185161590576171875
-
 =head2 pow
 
   sub pow : double ($x : double, $y : double)
