@@ -150,7 +150,7 @@ SPVM::Util - Variouse utilities
   my $objects = [(object)SPVM::Int->new(1), SPVM::Int->new(2), SPVM::Int->new(3)];
   my $objects_copy = copy_object_array($objects, sub : object ($self : self, $obj : object) {
     my $int_obj = (SPVM::Int)$obj;
-    my $new_int_obj = SPVM::Int->new($int_obj->val);
+    my $new_int_obj = SPVM::Int->new($int_obj->value);
     return $new_int_obj;
   });
   
@@ -365,12 +365,6 @@ Check if two string arrays equal.
 
 If at least one of the arrays is undefined, a excetpion occurs.
 
-=head2 E
-
-  sub E : double ()
-
-Get a napier number.
-
 =head2 get_type_name
 
   sub get_type_name : string ($obj : object)
@@ -1022,14 +1016,3 @@ Same as "index" function except that the search is the last of the string.
 
 If the string contains the sub string, return 1. If not, return 0.
 
-=head2 abs
-
-  sub abs : int ($x : int);
-
-Get the abusolute value of a int value.
-
-=head2 labs
-
-  sub labs : long ($x : long);
-
-Get the abusolute value for a long value.
